<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="612"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>Hardware Clock</source>
        <translation>Hardware Uhr</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Hardware Uhr Tools</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Hole Informationen von der Hardware Uhr und zeige sie in der Box Unten.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Hardware Uhr auslesen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Systematische Driftkorrekturen der Systemuhr durchführen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Driftkorrektur</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Zeit übertragen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Jetzt die Systemzeit auf Hardware Uhrzeit setzen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Hardware Zeit nach Systemzeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Jetzt die Hardware Uhr auf Systemzeit setzen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Systemzeit nach Hardware Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Aktualisierung des Driftfaktors beim Einstellen der Systemuhr. </translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Drift aktualisieren</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Zeitzone für die Hardware Uhr</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Ortszeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>UTC oder Greenwich Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Netzwerk Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Selektion nach Unten verschieben</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="449"/>
        <source>Move the selected item up</source>
        <translation>Selektion nach Oben verschieben</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="459"/>
        <source>Remove the current item from the list</source>
        <translation>Selektion von der Liste entfernen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="470"/>
        <source>Add an item to the list</source>
        <translation>Eintrag zur Liste hinzufügen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="496"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Die Uhrzeit automatisch mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="503"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Die Uhrzeit jetzt mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="506"/>
        <source>Update Now</source>
        <translation>Jetzt abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="518"/>
        <source>List of NTP servers to use.</source>
        <translation>Liste der benutzen NTP Server</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="534"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="539"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="544"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="279"/>
        <source>Reading...</source>
        <translation>Lese...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="293"/>
        <source>Adjusting...</source>
        <translation>Korrektur läuft ....</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>System Clock</source>
        <translation>Systemuhr</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="318"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Die %1 Zeit wurde von %2 übernommen.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="321"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Die %1 Zeit konnte von %2 nicht übernommen werden.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="360"/>
        <source>Updating...</source>
        <translation>Abgleich...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="373"/>
        <source>The system clock was updated successfully.</source>
        <translation>Die Systemzeit wurde erfolgreich synchronisiert.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="375"/>
        <source>The system clock could not be updated.</source>
        <translation>Die Systemzeit konnte nicht synchronisiert werden.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="377"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Keiner der NTP Server aus der Liste ist aktiviert.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="612"/>
        <source>About MX Date &amp; Time</source>
        <translation>Über MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="613"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="614"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafische Anwendung, um Datum und Uhrzeit in MX Linux einzustellen</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="616"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="618"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lizenz</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Änderungsprotokoll</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="624"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Datum &amp; Zeit Hilfe</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation type="unfinished">Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Schließen</translation>
    </message>
</context>
</TS>
